libtoolize --automake --copy --force 

aclocal --force
autoheader --force
automake --add-missing --gnu  --force-missing
autoconf

./configure --datadir=/usr/share --prefix=/usr
